@@ -127,7 +127,7 @@ class NmtField(object):
                 if wt.flip_ph:
                     maps = maps[:, :, ::-1]
                 maps = maps.reshape([len(maps), wt.npix])
-            except:
+            except (IndexError, ValueError):
                 raise ValueError("Input maps have the wrong shape")
 
         if isinstance(templates, (list, tuple, np.ndarray)):
@@ -143,7 +143,7 @@ class NmtField(object):
                     if wt.flip_ph:
                         templates = templates[:, :, :, ::-1]
                     templates = templates.reshape([ntemp, len(maps), wt.npix])
-                except:
+                except (IndexError, ValueError):
                     raise ValueError("Input templates have the wrong shape")
 
             if len(templates[0][0]) != len(mask):
@@ -197,9 +197,18 @@ class NmtField(object):
 
     def __del__(self):
         if self.fl is not None:
-            lib.field_free(self.fl)
+            if lib.field_free is not None:
+                lib.field_free(self.fl)
             self.fl = None
 
+    def get_mask(self):
+        """
+        Returns this field's mask as a 1D array.
+
+        :return: mask
+        """
+        return lib.get_mask(self.fl, int(self.fl.npix))
+
     def get_maps(self):
         """
         Returns a 2D array ([nmap][npix]) corresponding to the observed maps \
@@ -218,6 +227,22 @@ class NmtField(object):
             mps = maps
         return mps
 
+    def get_alms(self):
+        """
+        Returns a 2D array ([nmap][nlm]) corresponding to the observed \
+        harmonic coefficients of this field.
+
+        :return: 2D array of alms
+        """
+        if self.lite:
+            raise ValueError("Alms unavailable for lightweight fields")
+        alms = []
+        for imap in range(self.fl.nmaps):
+            alms.append(lib.get_alms(self.fl, imap, int(2*self.fl.nalms)))
+        alms = np.array(alms).reshape([self.fl.nmaps, self.fl.nalms, 2])
+        alms = alms[:, :, 0] + 1j * alms[:, :, 1]
+        return alms
+
     def get_templates(self):
         """
         Returns a 3D array ([ntemp][nmap][npix]) corresponding to the \
@@ -398,9 +423,22 @@ class NmtFieldFlat(object):
 
     def __del__(self):
         if self.fl is not None:
-            lib.field_flat_free(self.fl)
+            if lib.field_flat_free is not None:
+                lib.field_flat_free(self.fl)
             self.fl = None
 
+    def get_mask(self):
+        """
+        Returns this field's mask as a 2D array ([ny][nx]).
+
+        :return: 2D mask.
+        """
+        msk = lib.get_mask_flat(self.fl,
+                                int(self.fl.npix)).reshape([self.ny,
+                                                            self.nx])
+
+        return msk
+
     def get_maps(self):
         """
         Returns a 3D array ([nmap][ny][nx]) corresponding to the observed \
